@@ -556,7 +556,6 @@ class API(object):
     # The Visonic API URLs used
     __url_base = None
     __url_version = None
-    __url_is_panel_exists = None
     __url_login = None
     __url_panel_login = None
     __url_status = None
@@ -668,6 +667,10 @@ class API(object):
         if with_user_token:
             headers['User-Token'] = self.__user_token
 
+        logging.error('POST REQUEST -> ' + url)
+        logging.error(headers)
+        logging.error(data_json)
+
         # Perform the request and raise an exception
         # if the response is not OK (HTML 200)
         response = self.__session.post(url, headers=headers, data=data_json)
@@ -675,9 +678,13 @@ class API(object):
 
         # Check HTTP response code
         if response.status_code == requests.codes.ok:
-            return json.loads(response.content.decode('utf-8'))
+            resp = json.loads(response.content.decode('utf-8'))
+            logging.error(resp)
+
+            return resp
         else:
-            return response
+            logging.error(response)
+            return None
 
     ######################
     # Public API methods #
@@ -724,12 +731,6 @@ class API(object):
                                        with_user_token=False,
                                        with_session_token=False)
 
-    def get_panel_exists(self):
-        """ Check if our panel exists on the server. """
-        return self.__send_get_request(self.__url_is_panel_exists,
-                                       with_user_token=False,
-                                       with_session_token=False)
-
     def login(self):
         """ Try to login and get a user token. """
 
@@ -744,7 +745,6 @@ class API(object):
         res = self.__send_post_request(self.__url_login, login_json,
                                        with_user_token=False,
                                        with_session_token=False)
-        logging.info(res)
 
         self.__user_token = res['user_token']
 
@@ -763,7 +763,7 @@ class API(object):
         res = self.__send_post_request(self.__url_panel_login, panel_login_json,
                                         with_user_token=True,
                                         with_session_token=False)
-                                        
+        
         self.__session_token = res['session_token']
 
     def is_logged_in(self):
@@ -865,6 +865,7 @@ class API(object):
             'state': "HOME"
         }
         arm_json = json.dumps(arm_info, separators=(',', ':'))
+
         return self.__send_post_request(self.__url_set_state, arm_json,
                                         with_user_token=True,
                                         with_session_token=True)
@@ -876,6 +877,7 @@ class API(object):
             'state': "AWAY"
         }
         arm_json = json.dumps(arm_info, separators=(',', ':'))
+
         return self.__send_post_request(self.__url_set_state, arm_json,
                                         with_user_token=True,
                                         with_session_token=True)
@@ -887,6 +889,7 @@ class API(object):
             'state': "DISARM"
         }
         disarm_json = json.dumps(disarm_info, separators=(',', ':'))
+
         return self.__send_post_request(self.__url_set_state, disarm_json,
                                         with_user_token=True,
                                         with_session_token=True)
\ No newline at end of file
